app_name

Function app_name 

pub fn app_name(child: impl IntoUiNode, name: impl IntoVar<Txt>) -> UiNode
P Defines the display name of the product being setup.

The default value is zng::env::about().app, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_NAME_VAR.