app_org

Function app_org 

pub fn app_org(child: impl IntoUiNode, org: impl IntoVar<Txt>) -> UiNode
P Defines the display name of the producer of the product being setup.

The default value is zng::env::about().org, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_ORG_VAR.