app_version

Function app_version 

pub fn app_version(child: impl IntoUiNode, version: impl IntoVar<Txt>) -> UiNode
P Defines the display version of the product being setup.

The default value is zng::env::about().version, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_VERSION_VAR.