pub fn setup_op(
child: impl IntoUiNode,
setup_op: impl IntoVar<SetupOp>,
) -> UiNodeExpand description
P Defines what operation the wizard is configuring and running.
This property sets the SETUP_OP_VAR.
pub fn setup_op(
child: impl IntoUiNode,
setup_op: impl IntoVar<SetupOp>,
) -> UiNodeP Defines what operation the wizard is configuring and running.
This property sets the SETUP_OP_VAR.