#[non_exhaustive]pub struct FailedTaskInfoFnArgs {
pub info: TaskInfo,
pub errors: Vec<SetupTaskError>,
pub clean: bool,
}Expand description
Arguments for generating a task status UI.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.info: TaskInfoTask info.
errors: Vec<SetupTaskError>Task errors.
clean: boolIf all task changes where undone or task never committed changes.
If this is true and errors is empty the task never started.
If this is false and errors is empty the task completed successfully.