#[non_exhaustive]pub struct FinishAction {
pub info: Var<Txt>,
pub selected: Var<bool>,
pub action: Box<dyn FnOnce() -> Result<()> + Send + 'static>,
}Expand description
Represents an action that FinishPage runs once the wizard finishes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.info: Var<Txt>Short display info about the action.
selected: Var<bool>If the action should run.
If this var is modifiable the user will see an enabled checkbox for the action.
action: Box<dyn FnOnce() -> Result<()> + Send + 'static>Action to run.
The action will run blocking on the app context, on a FINISH_CMD preview handler. Note
that the setup app will likely exit just after this call, starting async tasks is not recommended.
Implementations