#[non_exhaustive]pub struct StatusPage {
pub status: Var<SetupStatus>,
pub task_infos: Vec<TaskInfo>,
pub task_info_fn: WidgetFn<StatusTaskInfoFnArgs>,
}Expand description
Setup operation status page.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Var<SetupStatus>The status displayed by the page.
Is SETUP::status by default.
task_infos: Vec<TaskInfo>Display info about setup task components of the operation that will run.
This task list is displayed on the same order as defined, as a check list with individual progress indicator.
If this list is empty or a task is not present only the overall operation progress indicator is shown.
task_info_fn: WidgetFn<StatusTaskInfoFnArgs>Widget that generates the status item for each item in task_infos.
Implementations
Sourceimpl StatusPage
impl StatusPage