SetupWizard

Struct SetupWizard 

pub struct SetupWizard(/* private fields */);
W Represents a setup operation wizard.

Implementations

Source

impl SetupWizard

pub fn widget_new() -> Self

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Source

impl SetupWizard

pub fn setup_op(&self, setup_op: impl IntoVar<SetupOp>)

P Defines what operation the wizard is configuring and running.

This property sets the SETUP_OP_VAR.

Source

impl SetupWizard

pub fn app_id(&self, id: impl IntoVar<Txt>)

P Defines the unique identifier of the product being setup.

This must be a globally unique identifier. A reverse DNS name is recommended.

The default value is zng::env::about().app_id, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_ID_VAR.

Source

impl SetupWizard

pub fn app_name(&self, name: impl IntoVar<Txt>)

P Defines the display name of the product being setup.

The default value is zng::env::about().app, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_NAME_VAR.

Source

impl SetupWizard

pub fn app_version(&self, version: impl IntoVar<Txt>)

P Defines the display version of the product being setup.

The default value is zng::env::about().version, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_VERSION_VAR.

Source

impl SetupWizard

pub fn app_org(&self, org: impl IntoVar<Txt>)

P Defines the display name of the producer of the product being setup.

The default value is zng::env::about().org, if the setup exe is also the product main exe this does not need to be set.

This property sets the APP_ORG_VAR.

Source

impl SetupWizard

pub fn installed_version(&self, version: impl IntoVar<Txt>)

P Defines the display version of the product that is already installed.

The default value is APP_VERSION_VAR, must be changed for SetupOp::Update.

This property sets the INSTALLED_VERSION_VAR.

Methods from Deref<Target = Wizard>

pub fn header_fn(&self, wgt_fn: impl IntoVar<WidgetFn<HeaderFnArgs>>)

P Widget function that converts a HeaderFnArgs into a page header container widget.

This property sets the HEADER_FN_VAR.

pub fn header_background_fn(&self, wgt_fn: impl IntoVar<WidgetFn<()>>)

P Widget function that makes a background visual for the page header container widget.

This property sets the HEADER_BACKGROUND_FN_VAR.

pub fn side_fn(&self, wgt_fn: impl IntoVar<WidgetFn<SideFnArgs>>)

P Widget function that converts a SideFnArgs into a page side container widget.

This property sets the SIDE_FN_VAR.

pub fn side_background_fn(&self, wgt_fn: impl IntoVar<WidgetFn<()>>)

P Widget function that makes a background visual for the page side container widget.

This property sets the SIDE_BACKGROUND_FN_VAR.

pub fn side_extra_fn(&self, side_extra_fn: impl IntoVar<WidgetFn<PageArgs>>)

P Widget function that converts PageArgs to extra side panel content.

Note that this extra content will only instantiate if the Page::side does not instantiate nil.

This property sets the SIDE_EXTRA_FN_VAR.

pub fn content_fn(&self, wgt_fn: impl IntoVar<WidgetFn<ContentFnArgs>>)

P Widget function that converts a ContentFnArgs into a page main content container container widget.

This property sets the CONTENT_FN_VAR.

pub fn footer_fn(&self, wgt_fn: impl IntoVar<WidgetFn<FooterFnArgs>>)

P Widget function that converts a FooterFnArgs into a page side container widget.

This property sets the FOOTER_FN_VAR.

pub fn footer_extra_fn(&self, footer_extra_fn: impl IntoVar<WidgetFn<PageArgs>>)

P Widget function that converts PageArgs to extra footer content.

This property sets the FOOTER_EXTRA_FN_VAR.

pub fn panel_fn(&self, wgt_fn: impl IntoVar<WidgetFn<PanelFnArgs>>)

P Widget function that converts a PanelFnArgs into a wizard.

This property sets the PANEL_FN_VAR.

pub fn pages(&self, pages: impl IntoVar<Vec<Page>>)

B Defines the wizard pages.

Pages are built on demand, the Page value defines wgt_fn! builders that are used by wizard when the page needs to be instantiated.

pub fn get_title(&self, title: impl IntoVar<Txt>)

P Get the current page title.

pub fn can_cancel(&self, enabled: impl IntoVar<bool>)

P Defines if on_cancel and on_pre_cancel command handlers are enabled in the widget and descendants.

Sets the CAN_CANCEL_VAR.

pub fn on_cancel( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard cancel requested.

Command

This property will subscribe to the CANCEL_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_cancel .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.

pub fn on_pre_cancel( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard cancel requested.

Command

This property will subscribe to the CANCEL_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_cancel .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.

pub fn can_begin(&self, enabled: impl IntoVar<bool>)

P Defines if on_begin and on_pre_begin command handlers are enabled in the widget and descendants.

Sets the CAN_BEGIN_VAR.

pub fn on_begin( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard begin requested.

Command

This property will subscribe to the BEGIN_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_begin .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.

pub fn on_pre_begin( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard begin requested.

Command

This property will subscribe to the BEGIN_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_begin .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.

pub fn can_finish(&self, enabled: impl IntoVar<bool>)

P Defines if on_finish and on_pre_finish command handlers are enabled in the widget and descendants.

Sets the CAN_FINISH_VAR.

pub fn on_finish( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard finish requested.

Command

This property will subscribe to the FINISH_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_finish .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.

pub fn on_pre_finish( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard finish requested.

Command

This property will subscribe to the FINISH_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_finish .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.

pub fn begin_cmd_name(&self, name: impl IntoVar<Txt>)

P Set the name for the BEGIN_CMD scoped on this widget.

pub fn finish_cmd_name(&self, name: impl IntoVar<Txt>)

P Set the name for the FINISH_CMD scoped on this widget.

Methods from Deref<Target = WidgetBase>

pub fn id(&self, id: impl IntoValue<WidgetId>)

B Unique ID of the widget instance.

Note that the id can convert from a &'static str unique name.