pub fn app_id(child: impl IntoUiNode, id: impl IntoVar<Txt>) -> UiNodeExpand description
P Defines the unique identifier of the product being setup.
This must be a globally unique identifier. A reverse DNS name is recommended.
The default value is zng::env::about().app_id, if the setup exe is also the product main exe
this does not need to be set.
This property sets the APP_ID_VAR.